rm(list=ls())

# libraries
require(lme4)
require(MuMIn)
require(corrplot)
require(car)
require(mgcv)
require(effects)
require(ggplot2)
require(lattice)

# data
wagner <- read.csv("Wagner_et_al_data_for_analysis.csv", h=T)
head(wagner)
summary(wagner)
wagner$Year <- factor(wagner$Year); is.factor(wagner$Year)
wagner$Patch <- factor(wagner$Patch); is.factor(wagner$Patch)

# scaling
sCoralProp <- scale(wagner$CoralProp)
sPatchVol  <- scale(wagner$PatchVol)
sDepth    <- scale(wagner$Depth)
sCaveProp <- scale(wagner$CaveProp)
sHoleProp <- scale(wagner$HoleProp)
sLdimAbund <- scale(wagner$LdimAbund)

# correlations
pairs(~ log(wagner$FishAbund) + PatchVol + Depth + CaveProp + CoralProp + LdimAbund + HoleProp, 
      data=wagner, panel=panel.smooth, main="Simple Scatterplot Matrix")
ct2<-wagner[,c(3:6,8:10)]; M2<-cor(ct2); corrplot(M2, method = "number")


#####################################
# Coral cover
#####################################

var.test(logit(wagner$CoralProp[wagner$Year==1997]), logit(wagner$CoralProp[wagner$Year==2007]), paired=T)
hist(logit(wagner[wagner$Year=="2007",]$CoralProp)); shapiro.test(logit(wagner[wagner$Year=="2007",]$CoralProp))
hist(logit(wagner[wagner$Year=="1997",]$CoralProp)); shapiro.test(logit(wagner[wagner$Year=="1997",]$CoralProp))
t.test(logit(wagner$CoralProp[wagner$Year==1997]), logit(wagner$CoralProp[wagner$Year==2007]), paired=T)


######################################
# Fish abundance
######################################

# gam 

sCorCav <- sCoralProp*sCaveProp
model1<-gam(log(FishAbund)~ s(sCoralProp)+ s(sPatchVol) + s(sDepth) + s(sCaveProp) + 
                           s(sHoleProp) + s(sLdimAbund) + s(sCorCav),  data=wagner)
plot(model1)

# full model

fa <- lmer(log(FishAbund) ~ Year + sCoralProp + sPatchVol + sDepth + sCaveProp + sHoleProp + 
            sLdimAbund + sCoralProp:sDepth + sCoralProp:sCaveProp + sPatchVol:sCaveProp + 
		sDepth:sCaveProp +sDepth:sLdimAbund + sCaveProp:sHoleProp + sHoleProp:sLdimAbund +
		I(sPatchVol^2) + (1|Patch), data = wagner, REML=F) 

# diagnostic plots

plot(fa)
qqPlot(resid(fa))
qqPlot(ranef(fa , drop = TRUE)[["Patch"]])

# model selection with MuMIn

options(na.action = "na.fail")
faIT <-dredge(fa)
summary(get.models(faIT, 1)[[1]]) # 'best' model
subset(faIT, delta < 4.6)
model.avg(faIT, subset = delta < 4.6)
faITavg <- model.avg(faIT, subset = delta < 4.6)
summary(faITavg) # gives Delta and Weights for model subset, model averaged coeficients and SEs, and relative variable importance

# final model

fa.final <- lmer(log(FishAbund) ~ Year + sCoralProp + sPatchVol + sDepth + sCaveProp + sHoleProp + 
            sLdimAbund + sCoralProp:sCaveProp + sPatchVol:sCaveProp + sCaveProp:sHoleProp +
		I(sPatchVol^2) + (1|Patch), data = wagner, REML=F)

r.squaredGLMM(fa.final)

# effect plots

plot(effect("sCoralProp", fa.final))
plot(effect("sPatchVol", fa.final))
plot(effect("sCaveProp", fa.final))
plot(effect("sLdimAbund", fa.final))
plot(effect("sCoralProp:sCaveProp", fa.final))
plot(effect("sPatchVol:sCaveProp", fa.final))

# raw data plots

#1997

wag1997 <- wagner[wagner$Year=="1997",]

wag1997$Fcoral <- factor(cut(wag1997$CoralProp, quantile(wag1997$CoralProp), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishAbund~CaveProp|Fcoral, data=wag1997, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish abundance", col="blue")

wag1997$Fvol <- factor(cut(wag1997$PatchVol, quantile(wag1997$PatchVol), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishAbund~CaveProp|Fvol, data=wag1997, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish abundance", col="blue")

#2007

wag2007 <- wagner[wagner$Year=="2007",]

wag2007$Fcoral <- factor(cut(wag2007$CoralProp, quantile(wag2007$CoralProp), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishAbund~CaveProp|Fcoral, data=wag2007, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish abundance", col="blue")

wag2007$Fvol <- factor(cut(wag2007$PatchVol, quantile(wag2007$PatchVol), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishAbund~CaveProp|Fvol, data=wag2007, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish abundance", col="blue")


######################################
# Fish species richness
######################################

# gam 

model2<-gam(log(FishRich)~ s(sCoralProp)+ s(sPatchVol) + s(sDepth) + s(sCaveProp) + 
                           s(sHoleProp) + s(sLdimAbund) + s(sCorCav),  data=wagner)
plot(model2)

# full model

fr <- lmer(FishRich ~ Year + sCoralProp + sPatchVol + sDepth + sCaveProp + sHoleProp + 
            sLdimAbund + I(sPatchVol^2) + sCoralProp:sDepth + sCoralProp:sCaveProp + sPatchVol:sCaveProp +
		sPatchVol:sHoleProp + sCaveProp:sLdimAbund + sHoleProp:sLdimAbund + (1|Patch), data = wagner, REML=F)

#diagnostic plots

plot(fr)
qqPlot(resid(fr))
qqPlot(ranef(fr , drop = TRUE)[["Patch"]])

# model selection

options(na.action = "na.fail")
frIT <-dredge(fr) #extra=c("R^2", "adjR^2"))

summary(get.models(frIT, 1)[[1]]) # 'best' model
subset(frIT, delta < 4.6)
model.avg(frIT, subset = delta < 4.6)
frITavg <- model.avg(frIT, subset = delta < 4.6)
summary(frITavg) # gives Delta and Weights for model subset, model averaged coeficients and SEs, and relative variable importance
plot(importance(frITavg)) # contained in summary(model.avg()) above, gives the relative variable importance

# final model

fr.final <- lmer(FishRich ~ Year + sCoralProp + sPatchVol + sDepth + sCaveProp + sHoleProp + 
            sLdimAbund + I(sPatchVol^2) + sCoralProp:sDepth + sCoralProp:sCaveProp + sPatchVol:sCaveProp +
		sPatchVol:sHoleProp + (1|Patch), data = wagner, REML=F)
r.squaredGLMM(fr.final)

# effect plots

plot(effect("Year", fr.final))
plot(effect("sCoralProp", fr.final))
plot(effect("sDepth", fr.final)) 
plot(effect("sLdimAbund", fr.final))
plot(effect("sCaveProp", fr.final))
plot(effect("sHoleProp", fr.final))
plot(effect("sPatchVol", fr.final)) 
plot(effect("sPatchVol^2", fr.final))
plot(effect("sPatchVol:sCaveProp", fr.final))
plot(effect("sPatchVol:sHoleProp", fr.final))
plot(effect("sCoralProp:sDepth", fr.final))

# raw data plots

xyplot(FishRich~LdimAbund, group = Year, data=wagner, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = c("dark blue", "light blue"), col = c("dark blue", "light blue"), pch = 19, cex = 1, xlab="L. dimidiatus abundance", ylab="Fish species richness")

#1997

wag1997$Fvol <- factor(cut(wag1997$PatchVol, quantile(wag1997$PatchVol), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~CaveProp|Fvol, data=wag1997, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish species richness", col="blue")

wag1997$Fhole <- factor(cut(wag1997$HoleProp, quantile(wag1997$HoleProp), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~PatchVol|Fhole, data=wag1997, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Patch volume", ylab="Fish species richness", col="blue")

wag1997$Fdepth <- factor(cut(wag1997$Depth, quantile(wag1997$Depth), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~CoralProp|Fdepth, data=wag1997, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent live coral cover", ylab="Fish species richness", col="blue")

#2007

wag2007$Fvol <- factor(cut(wag2007$PatchVol, quantile(wag2007$PatchVol), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~CaveProp|Fvol, data=wag2007, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent caves", ylab="Fish species richness", col="blue")

wag2007$Fhole <- factor(cut(wag2007$HoleProp, quantile(wag2007$HoleProp), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~PatchVol|Fhole, data=wag2007, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Patch volume", ylab="Fish species richness", col="blue")

wag2007$Fdepth <- factor(cut(wag2007$Depth, quantile(wag2007$Depth), include.lowest = TRUE), labels = LETTERS[1:4])
xyplot(FishRich~CoralProp|Fdepth, data=wag2007, type=c("p", "smooth"), lwd = 3, lty = 3, col.line = "grey", pch = 19, cex = 1, xlab="Percent live coral cover", ylab="Fish species richness", col="blue")
